@@ -19,6 +19,7 @@
 #'      * `intens_grid_cells`: im object of observed densities for each time period
 #'      * `estimated_counts`: the number of events that is estimated by the poisson point process model for each time period
 #'      * `sum_log_intens`: the sum of log intensities for each time period
+#'      * `actual_counts`: the number of events (actual counts)
 #'
 #' @details `get_obs_dens()` assumes the poisson point process model and
 #' calculates observed densities for each time period. It depends on `spatstat.model::mppm()`.
@@ -45,11 +46,15 @@ get_obs_dens <- function(hfr, dep_var, indep_var, ngrid = 100, window) {
     return(r)
   })
 
+  # Get the number of actual counts -----
+  actual_counts <- unlist(purrr::map(hfr[[dep_var]], function(x) x$n))
+
   out <- list(indep_var = indep_var, #List of independent variables
               coef = coefficients, #Coefficients
               intens_grid_cells = intensity_grid_cells, #Integrated intensity as images
-              estimated_counts = estimated_counts, #Counts
-              sum_log_intens = sum_log_intensity) #Sum of log(intensity) for each time period
+              estimated_counts = estimated_counts, #Estimated Counts
+              sum_log_intens = sum_log_intensity, #Sum of log(intensity) for each time period
+              actual_counts = actual_counts) #Actual counts
 
   class(out) <- c("obs", "list")
   return(out)
